﻿using UnityEngine;

namespace Mod
{
    public class Mod
    {
        public static void Main()
        {
            CategoryBuilder.Create("GTA III", "Grand Theft Auto III mod category", ModAPI.LoadSprite("icon.png"));

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Baseball Bat"),
                    NameOverride = "Baseball Bat -GTAIII",
                    NameToOrderByOverride = "1",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/batthumb.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/bat.png");

                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                NameOverride = "Pistol -GTAIII",
                NameToOrderByOverride = "2",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/pistolthumb.png"),
                AfterSpawn = (Instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    var PistolSlide = Instance.transform.Find("Slide");
                    PistolSlide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/pistolslide.png");

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/pistol.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "9mm";
                    customCartridge.Damage *= 2f;
                    customCartridge.StartSpeed *= 1.6f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 0.6f;
                    customCartridge.Recoil *= 0.6f;
                    customCartridge.ImpactForce *= 0.7f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                NameOverride = "Uzi -GTAIII",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                NameToOrderByOverride = "2",
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/uzithumb.png"),
                AfterSpawn = (Instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    var MicroUziSlide = Instance.transform.Find("Slide");
                    MicroUziSlide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/uzislide.png");

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/uzi.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "9×19mm";
                    customCartridge.Damage *= 1.85f;
                    customCartridge.StartSpeed *= 1.5f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 0.6f;
                    customCartridge.Recoil *= 0.7f;
                    customCartridge.ImpactForce *= 0.7f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.185f, 0.125f);
                    Instance.GetComponent<FirearmBehaviour>().Automatic = true;
                    Instance.GetComponent<FirearmBehaviour>().AutomaticFireInterval = 0.07f; //0.07f;
    }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("Shotgun"),
                NameOverride = "Shotgun -GTAIII",
                NameToOrderByOverride = "3",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/shotgunthumb.png"),
                AfterSpawn = (Instance) =>
                {
                    var Weapon = Instance.transform;
                    var Cover = new GameObject("Cover");
                    Cover.transform.SetParent(Weapon);
                    Cover.transform.localPosition = new Vector3(0f, 0f);
                    Cover.transform.rotation = Weapon.rotation;
                    Cover.transform.localScale = new Vector3(1f, 1f);
                    var CoverSprite = Cover.AddComponent<SpriteRenderer>();
                    CoverSprite.sprite = ModAPI.LoadSprite("Sprites/shotguncover.png");
                    CoverSprite.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();

                    var ShotgunSlide = Instance.transform.Find("Slide");
                    ShotgunSlide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/shotgunslide.png");
                    ShotgunSlide.GetComponent<SpriteRenderer>().color = Color.white;
                    ShotgunSlide.localScale = new Vector3(1f, 1f);
                    var ShotgunCover = Instance.transform.Find("Cover");
                    ShotgunCover.gameObject.AddComponent<PhysicalBehaviour>().Disintegrate();

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/shotgun.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "9mm";
                    customCartridge.Damage *= 6f;
                    customCartridge.StartSpeed *= 1.2f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 0.7f;
                    customCartridge.Recoil *= 2f;
                    customCartridge.ImpactForce *= 0.8f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.71f, 0.115f);
                }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = "AK47 -GTAIII",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                NameToOrderByOverride = "3",
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/akthumb.png"),
                AfterSpawn = (Instance) =>
                {
                    var Weapon = Instance.transform;
                    var Cover = new GameObject("Cover");
                    Cover.transform.SetParent(Weapon);
                    Cover.transform.localPosition = new Vector3(0f, 0f);
                    Cover.transform.rotation = Weapon.rotation;
                    Cover.transform.localScale = new Vector3(1f, 1f);
                    var CoverSprite = Cover.AddComponent<SpriteRenderer>();
                    CoverSprite.sprite = ModAPI.LoadSprite("Sprites/akcover.png");
                    CoverSprite.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();

                    var AKSlide = Instance.transform.Find("Slide");
                    AKSlide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/akslide.png");
                    AKSlide.GetComponent<SpriteRenderer>().sortingOrder = Instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/ak.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "9×19mm";
                    customCartridge.Damage *= 2.75f;
                    customCartridge.StartSpeed *= 1.75f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 0.7f;
                    customCartridge.Recoil *= 0.6f;
                    customCartridge.ImpactForce *= 0.6f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().Automatic = true;
                    Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.67f, 0.11f);
                    Instance.GetComponent<FirearmBehaviour>().AutomaticFireInterval = 0.065f; //0.07f;
    }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = "M16 -GTAIII",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                NameToOrderByOverride = "3",
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/m16thumb.png"),
                AfterSpawn = (Instance) =>
                {
                    var Weapon = Instance.transform;
                    var Cover = new GameObject("Cover");
                    Cover.transform.SetParent(Weapon);
                    Cover.transform.localPosition = new Vector3(0f, 0f);
                    Cover.transform.rotation = Weapon.rotation;
                    Cover.transform.localScale = new Vector3(1f, 1f);
                    var CoverSprite = Cover.AddComponent<SpriteRenderer>();
                    CoverSprite.sprite = ModAPI.LoadSprite("Sprites/m16cover.png");
                    CoverSprite.sortingOrder = 7;

                    ModAPI.KeepExtraObjects();

                    var M16Slide = Instance.transform.Find("Slide");
                    M16Slide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/m16slide.png");
                    M16Slide.GetComponent<SpriteRenderer>().sortingOrder = Instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/m16.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "9×19mm";
                    customCartridge.Damage *= 4f;
                    customCartridge.StartSpeed *= 2f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 0.65f;
                    customCartridge.Recoil *= 0.35f;
                    customCartridge.ImpactForce *= 0.55f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().Automatic = true;
                    Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.76f, 0.07f);
                    Instance.GetComponent<FirearmBehaviour>().AutomaticFireInterval = 0.03f; //0.07f;
    }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                NameOverride = "Sniper Rifle -GTAIII",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                NameToOrderByOverride = "3",
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/riflethumb.png"),
                AfterSpawn = (Instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    var SniperRifleSlide = Instance.transform.Find("Slide");
                    SniperRifleSlide.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/rifleslide.png");
                    SniperRifleSlide.GetComponent<SpriteRenderer>().sortingOrder = Instance.GetComponent<SpriteRenderer>().sortingOrder + 1;

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/rifle.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "9×19mm";
                    customCartridge.Damage *= 5f;
                    customCartridge.StartSpeed *= 2.25f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 0.75f;
                    customCartridge.Recoil *= 0.2f;
                    customCartridge.ImpactForce *= 0.6f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.75f, 0.06f);
                }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("Rocket Launcher"),
                NameOverride = "Rocket Launcher -GTAIII",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                NameToOrderByOverride = "4",
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/rocketthumb.png"),
                AfterSpawn = (Instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/rocket.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
                    Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

                    var firearm = Instance.GetComponent<FirearmBehaviour>();

                    Cartridge customCartridge = ModAPI.FindCartridge("9mm");
                    customCartridge.name = "40mm";
                    customCartridge.Damage *= 50f;
                    customCartridge.StartSpeed *= 3.5f;
                    customCartridge.PenetrationRandomAngleMultiplier *= 1f;
                    customCartridge.Recoil *= 0.2f;
                    customCartridge.ImpactForce *= 1f;
                    firearm.Cartridge = customCartridge;

                    Instance.FixColliders();
                }
            }
            );

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("Flamethrower"),
                NameOverride = "Flamethrower -GTAIII",
                DescriptionOverride = "",
                CategoryOverride = ModAPI.FindCategory("GTA III"),
                NameToOrderByOverride = "4",
                ThumbnailOverride = ModAPI.LoadSprite("Thumbs/flamethrowerthumb.png"),
                AfterSpawn = (Instance) =>
                {
                    ModAPI.KeepExtraObjects();

                    Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/flamethrower.png");
                    foreach (var c in Instance.GetComponents<Collider2D>())
                    {
                        GameObject.Destroy(c);
                    }
                    Instance.FixColliders();
        //Instance.GetComponent<FirearmBehaviour>().BulletsPerShot = 1;

        var firearm = Instance.GetComponent<FirearmBehaviour>();

        /*Cartridge customCartridge = ModAPI.FindCartridge("9mm");
        customCartridge.name = "40mm";
        customCartridge.Damage *= 50f;
        customCartridge.StartSpeed *= 3.5f;
        customCartridge.PenetrationRandomAngleMultiplier *= 1f;
        customCartridge.Recoil *= 0.2f;
        customCartridge.ImpactForce *= 1f;
        firearm.Cartridge = customCartridge;*/

                    Instance.FixColliders();
                }
            }
            );

            ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Handgrenade"),
        NameOverride = "Grenade -GTAIII",
        NameToOrderByOverride = "8",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/grenadethumb.png"),
        AfterSpawn = (Instance) =>
        {
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/grenade.png");
            Instance.FixColliders();
        }
    }
);

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
                    NameOverride = "Molotov Cocktail -GTAIII",
                    NameToOrderByOverride = "8",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/molotovthumb.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/molotov.png");
                        Instance.GetComponent<PhysicalBehaviour>().Properties = ModAPI.FindPhysicalProperties("Glass");
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 10f;
                        Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 0.75f;
                        Instance.GetComponent<ExplosiveBehaviour>().ExplodeBurnProgressThreshold = 10f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveStrength = 0f;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentForce = 0f;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = 2f;
                        Instance.GetComponent<ExplosiveBehaviour>().DismemberChance = 0;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = 2f;
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.20f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.20f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0.20f;
                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"),
                    NameOverride = "Claude -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/claudethumb.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var skin = ModAPI.LoadTexture("Sprites/claude.png");

                        var person = Instance.GetComponent<PersonBehaviour>();

                        person.SetBodyTextures(skin, null, null, 1);

                        person.SetBruiseColor(67, 65, 65);
                        person.SetSecondBruiseColor(154, 0, 7);
                        person.SetThirdBruiseColor(64, 64, 64);
                        person.SetRottenColour(202, 199, 104);
                        person.SetBloodColour(108, 0, 4);
                    }
                }
            );

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Leone Family Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/mafiathumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/mafia.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Triad Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/triadthumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/triads.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/triadshat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Diablos Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/diablothumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/diablo.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/diablohat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Diablos Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/diablothumb2.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/diablo2.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/diablohat2.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);



            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"),
                    NameOverride = "Colombian Cartel Member -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/cartelthumb.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var skin = ModAPI.LoadTexture("Sprites/cartel.png");

                        var person = Instance.GetComponent<PersonBehaviour>();

                        person.SetBodyTextures(skin, null, null, 1);

                        person.SetBruiseColor(67, 65, 65);
                        person.SetSecondBruiseColor(154, 0, 7);
                        person.SetThirdBruiseColor(64, 64, 64);
                        person.SetRottenColour(202, 199, 104);
                        person.SetBloodColour(108, 0, 4);

                        var head = Instance.transform.GetChild(5);
                        var childObject = new GameObject("Helmet");
                        childObject.transform.SetParent(head);
                        childObject.transform.localPosition = new Vector3(0, 0f);
                        childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
                        childObject.transform.localScale = new Vector3(1f, 1f);
                        var childSprite = childObject.AddComponent<SpriteRenderer>();
                        childSprite.sprite = ModAPI.LoadSprite("Sprites/hat.png");
                        childSprite.sortingLayerName = "Top";
                    }
                }
            );

            ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Colombian Cartel Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/cartelthumb2.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/cartel2.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/hat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

            /*ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Colombian Cartel Hat -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/hatthumb.png"),
                    AfterSpawn = (Instance) =>

                    {
                        Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/hat.png", 1f);
                        Instance.FixColliders();


                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/hat.png", 1f);
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0.5f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;

                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
                        Instance.FixColliders();
                    }
                }
            );*/

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Yakuza Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/yakuzathumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/yakuza.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Yakuza Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/yakuzathumb2.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/yakuza2.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);
        }
    }
);

            ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Uptown Yardie Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/yardiethumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/yardie.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/yardiehair.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Southside Hoods (Purple Nines) Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/hoodsthumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/hoods.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/hoodshat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Southside Hoods (Red Jacks) Member -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/hoodsthumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/hoods2.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/hoodshat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"),
                    NameOverride = "Police Officer -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/policethumb.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var skin = ModAPI.LoadTexture("Sprites/police.png");

                        var person = Instance.GetComponent<PersonBehaviour>();

                        person.SetBodyTextures(skin, null, null, 1);

                        person.SetBruiseColor(67, 65, 65);
                        person.SetSecondBruiseColor(154, 0, 7);
                        person.SetThirdBruiseColor(64, 64, 64);
                        person.SetRottenColour(202, 199, 104);
                        person.SetBloodColour(108, 0, 4);

                        var head = Instance.transform.GetChild(5);
                        var childObject = new GameObject("Helmet");
                        childObject.transform.SetParent(head);
                        childObject.transform.localPosition = new Vector3(0, 0f);
                        childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
                        childObject.transform.localScale = new Vector3(1f, 1f);
                        var childSprite = childObject.AddComponent<SpriteRenderer>();
                        childSprite.sprite = ModAPI.LoadSprite("Sprites/policehat.png");
                        childSprite.sortingLayerName = "Top";
                    }
                }
            );

            /*ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Police Officer Hat -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/policehatthumb.png"),
                    AfterSpawn = (Instance) =>

                    {
                        Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/policehat.png", 1f);
                        Instance.FixColliders();


                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/policehat.png", 1f);
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0.5f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;

                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
                        Instance.FixColliders();
                    }
                }
            );*/

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "SWAT -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/swatthumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/swat.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);
        }
    }
);

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "SWAT Helmet -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/swathelmetthumb.png"),
                    AfterSpawn = (Instance) =>

                    {
                        Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/swathelmet.png", 1f);
                        Instance.FixColliders();


                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/swathelmet.png", 1f);
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = -1f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 15;

                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
                        Instance.FixColliders();
                    }
                }
            );

            ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "FIB Agent -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/fbithumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/fbi.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/fbihat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

/*ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Stick"),
        NameOverride = "FIB Agent Hat -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/batthumb.png"),
        AfterSpawn = (Instance) =>

        {
            Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/fbihat.png", 1f);
            Instance.FixColliders();


            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/fbihat.png", 1f);
            ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

            armor.stabResistance = 1.5f;
            armor.armorPiece = "Head";
            armor.armorTier = 0;

            Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
            Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
            Instance.FixColliders();
        }
    }
);*/

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"),
                    NameOverride = "Soldier -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/armythumb.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var skin = ModAPI.LoadTexture("Sprites/military.png");

                        var person = Instance.GetComponent<PersonBehaviour>();

                        person.SetBodyTextures(skin, null, null, 1);

                        person.SetBruiseColor(67, 65, 65);
                        person.SetSecondBruiseColor(154, 0, 7);
                        person.SetThirdBruiseColor(64, 64, 64);
                        person.SetRottenColour(202, 199, 104);
                        person.SetBloodColour(108, 0, 4);
                    }
                }
            );

            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Soldier Helmet -GTAIII",
                    DescriptionOverride = "",
                    CategoryOverride = ModAPI.FindCategory("GTA III"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbs/helmetthumb.png"),
                    AfterSpawn = (Instance) =>

                    {
                        Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/helmet.png", 1f);
                        Instance.FixColliders();


                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/helmet.png", 1f);
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = -1f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 15;

                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
                        Instance.FixColliders();
                    }
                }
            );

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Medic -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/medicthumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/medic.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);

            var head = Instance.transform.GetChild(5);
            var childObject = new GameObject("Helmet");
            childObject.transform.SetParent(head);
            childObject.transform.localPosition = new Vector3(0, 0f);
            childObject.transform.rotation = Quaternion.Euler(0f, 0f, 0f);
            childObject.transform.localScale = new Vector3(1f, 1f);
            var childSprite = childObject.AddComponent<SpriteRenderer>();
            childSprite.sprite = ModAPI.LoadSprite("Sprites/medichat.png");
            childSprite.sortingLayerName = "Top";
        }
    }
);

/*ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Stick"),
        NameOverride = "Medic Hat -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/batthumb.png"),
        AfterSpawn = (Instance) =>

        {
            Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/medichat.png", 1f);
            Instance.FixColliders();


            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/medichat.png", 1f);
            ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

            armor.stabResistance = 1.5f;
            armor.armorPiece = "Head";
            armor.armorTier = 0;

            Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
            Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
            Instance.FixColliders();
        }
    }
);*/

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "Fireman -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/firemanthumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("Sprites/fireman.png");

            var person = Instance.GetComponent<PersonBehaviour>();

            person.SetBodyTextures(skin, null, null, 1);

            person.SetBruiseColor(67, 65, 65);
            person.SetSecondBruiseColor(154, 0, 7);
            person.SetThirdBruiseColor(64, 64, 64);
            person.SetRottenColour(202, 199, 104);
            person.SetBloodColour(108, 0, 4);
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Rod"),
        NameOverride = "Fireman Helmet -GTAIII",
        DescriptionOverride = "",
        CategoryOverride = ModAPI.FindCategory("GTA III"),
        ThumbnailOverride = ModAPI.LoadSprite("Thumbs/firemanhelmetthumb.png"),
        AfterSpawn = (Instance) =>

        {
            Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Foreground";
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/firemanhelmet.png", 1f);
            Instance.FixColliders();


            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/firemanhelmet.png", 1f);
            ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

            armor.stabResistance = -1f;
            armor.armorPiece = "Head";
            armor.armorTier = 8;

            Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.03f;
            Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.03f;
            Instance.FixColliders();
        }
    }
);

            //21 из 79
            //2 из 12
        }
    }
}